@@ -21,4 +21,7 @@ STILTFP = '/data/stiltweb/slots/'
 STILTINFO = 'https://stilt.icos-cp.eu/viewer/stationinfo'
 
 # online results
-STILTTS = 'https://stilt.icos-cp.eu/viewer/stiltresult'
\ No newline at end of file
+STILTTS = 'https://stilt.icos-cp.eu/viewer/stiltresult'
+
+# stiltresults all columns, raw
+STILTRAW = 'https://stilt.icos-cp.eu/viewer/stiltrawresult'
\ No newline at end of file
